summaryrefslogtreecommitdiffstats
path: root/korganizer/actionmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/actionmanager.cpp')
-rw-r--r--korganizer/actionmanager.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/korganizer/actionmanager.cpp b/korganizer/actionmanager.cpp
index ad6c7e36..cbb4e42f 100644
--- a/korganizer/actionmanager.cpp
+++ b/korganizer/actionmanager.cpp
@@ -314,7 +314,7 @@ void ActionManager::initActions()
mACollection, "edit_delete" );
if ( mIsPart ) {
KStdAction::find( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
- mACollection, "korganizer_tqfind" );
+ mACollection, "korganizer_find" );
} else {
KStdAction::find( mCalendarView->dialogManager(), TQT_SLOT( showSearchDialog() ),
mACollection );
@@ -402,7 +402,7 @@ void ActionManager::initActions()
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ZOOM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
// TODO: try to tqfind / create better icons for the following 4 actions
new KAction( i18n( "Zoom In Horizontally" ), "viewmag+", 0,
mCalendarView->viewManager(), TQT_SLOT( zoomInHorizontally() ),
mACollection, "zoom_in_horizontally" );
@@ -998,7 +998,7 @@ bool ActionManager::saveURL()
if ( result != KMessageBox::Continue ) return false;
TQString filename = mURL.fileName();
- filename.tqreplace( filename.length() - 4, 4, ".ics" );
+ filename.replace( filename.length() - 4, 4, ".ics" );
mURL.setFileName( filename );
if ( mURL.isLocalFile() ) {
mFile = mURL.path();
@@ -1708,11 +1708,11 @@ void ActionManager::openEventEditor( const TQString & summary,
return;
// due to kmime shortcomings in KDE3, we need to assemble the result manually
int begin = 0;
- int end = head.tqfind( '\n' );
+ int end = head.find( '\n' );
bool skipFolded = false;
while ( end >= 0 && end > begin ) {
- if ( head.tqfind( "Content-Type:", begin, false ) != begin &&
- head.tqfind( "Content-Transfer-Encoding:", begin, false ) != begin &&
+ if ( head.find( "Content-Type:", begin, false ) != begin &&
+ head.find( "Content-Transfer-Encoding:", begin, false ) != begin &&
!(skipFolded && (head[begin] == ' ' || head[end] == '\t')) ) {
TQCString line = head.mid( begin, end - begin );
tf.file()->writeBlock( line.data(), line.length() );
@@ -1723,7 +1723,7 @@ void ActionManager::openEventEditor( const TQString & summary,
}
begin = end + 1;
- end = head.tqfind( '\n', begin );
+ end = head.find( '\n', begin );
if ( end < 0 && begin < (int)head.length() )
end = head.length() - 1;
}
@@ -402,7 +402,7 @@ void ActionManager::initActions()
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ ZOOM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
- // TODO: try to tqfind / create better icons for the following 4 actions
+ // TODO: try to find / create better icons for the following 4 actions
new KAction( i18n( "Zoom In Horizontally" ), "viewmag+", 0,
mCalendarView->viewManager(), TQT_SLOT( zoomInHorizontally() ),